/*
 * Lancaster University
 * Computing Department
 * 
 * Created by Eduardo Figueiredo
 * Date: 11 Aug 2007
 * 
 */
package lancs.mobilemedia.core.ui.controller;

import javax.microedition.lcdui.Alert;
import javax.microedition.lcdui.AlertType;
import javax.microedition.lcdui.Command;
import javax.microedition.lcdui.Display;
import javax.microedition.lcdui.List;

import lancs.mobilemedia.lib.exceptions.UnavailablePhotoAlbumException;
import lancs.mobilemedia.core.ui.MainUIMidlet;
import lancs.mobilemedia.core.ui.datamodel.AlbumData;


import lancs.mobilemedia.core.ui.datamodel.MediaData;
import lancs.mobilemedia.core.ui.screens.AlbumListScreen;
import lancs.mobilemedia.core.ui.screens.MediaListScreen;
import lancs.mobilemedia.core.util.Constants;

/**
 * @author Eduardo Figueiredo
 * 
 */
public class MediaListController extends AbstractController {

	/**
	 * @param midlet
	 * @param nextController
	 * @param albumData
	 * @param albumListScreen
	 */
	public MediaListController(MainUIMidlet midlet, AlbumData albumData,
			AlbumListScreen albumListScreen) {
		super(midlet, albumData, albumListScreen);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * lancs.mobilemedia.core.ui.controller.ControllerInterface#handleCommand
	 * (java.lang.String)
	 */
	public boolean handleCommand(Command command) {
		String label = command.getLabel();
		/** Case: Select PhotoAlbum to view **/
		if (label.equals("Select")) {
			// Get the name of the PhotoAlbum selected, and load image list from
			// RecordStore
			List down = (List) Display.getDisplay(midlet).getCurrent();
			ScreenSingleton.getInstance().setCurrentStoreName(
					down.getString(down.getSelectedIndex()));
			showMediaList(getCurrentStoreName(), false, false);
			ScreenSingleton.getInstance().setCurrentScreenName(
					Constants.IMAGELIST_SCREEN);
			return true;
		}

		return false;
	}

	/**
	 * Show the list of images in the record store TODO: Refactor - Move this to
	 * ImageList class
	 */
	public void showMediaList(String recordName, boolean sort, boolean favorite) {
		if (recordName == null)
			recordName = getCurrentStoreName();

		// generic AbstractController
		MediaController mediaController = new MediaController(midlet,
				getAlbumData(), (AlbumListScreen) getAlbumListScreen());
		mediaController.setNextController(this);

		// defines the type of screen: Photo or Video
		MediaListScreen mediaList = null;
		mediaList = selectScreen(mediaList);

		mediaList.setCommandListener(mediaController);

		// Command selectCommand = new Command("Open", Command.ITEM, 1);
		mediaList.initMenu();

		MediaData[] medias = null;
		try {
			medias = getAlbumData().getMedias(recordName);
		} catch (UnavailablePhotoAlbumException e) {
			Alert alert = new Alert("Error",
					"The list of items can not be recovered", null,
					AlertType.ERROR);
			Display.getDisplay(midlet).setCurrent(alert,
					Display.getDisplay(midlet).getCurrent());
			return;
		}

		if (medias == null)
			return;

		adjustMedias(sort, medias);

		// loop through array and add labels to list
		for (int i = 0; i < medias.length; i++) {
			if (medias[i] != null) {
				// Add album name to menu list

				addAlbumNameToMenuList(favorite, mediaList, medias, i);

			}
		}
		setCurrentScreen(mediaList);
		// currentMenu = "list";
	}


	private MediaListScreen selectScreen(MediaListScreen mediaList) {
		return mediaList;
	}

	private void adjustMedias(boolean sort, MediaData[] medias) {}
	
	private void addAlbumNameToMenuList(boolean favorite,
			MediaListScreen mediaList, MediaData[] medias, int i) {
		mediaList.append(medias[i].getMediaLabel(), null);
	}


}
